==> T2GEORES-0.1.8.tar.gz: T2GEORES-0.1.8/T2GEORES/formats.py <==
"""
The file contains several dictionaries which declare the format and default values from most of the parameters
for modeling.

formats_t2: represents the parameters from TOUGH2 base on sections. For instance, 'PARAMETERS' is a dictionary, every data
on it is formatted as following: 'PARAMETER1':[Default value,format,line section].

plot_conf_color: it gives three color for every main output parameter, the first is for real data, second for current output and final for 
previous run.

plot_conf_marker: gives the marker type and alpha value depending on the the of data in case same color is used when plotting.

structure: gives the fix structure of T2GEORES, necessary as workspace.

"""


initial_conditions={'EOS1':[
						    [100E5,'>20.13E',4,'P'],
						    [250,'>20.13E',4,'T'],
						    [1e5,'>20.13E',4,'X']]}

formats_t2={'TITLE':['TOUGH2 INPUT FILE','<80s',1],
			'ROCKS':{
					'MAT':[None,'>5s',1],
					'NAD':[None,'>5s',1],
					'DROK':[None,'>10.3E',1],
					'POR':[None,'>10.3E',1],
					'PER_X':[None,'>10.3E',1],
					'PER_Y':[None,'>10.3E',1],
					'PER_Z':[None,'>10.3E',1],
					'CWET':[None,'>10.3E',1],
					'SPHT':[None,'>10.3E',1],
					'COM':[None,'>10.3E',2],
					'EXPAN':[None,'>10.3E',2],
					'CDRY':[None,'>10.3E',2],
					'TORTX':[None,'>10.3E',2],
					'GK':[None,'>10.3E',2],
					'XKD3':[None,'>10.3E',2],
					'XKD4':[None,'>10.3E',2],
					'IRP':[None,'>5s',3],
					'SPACE':[None,'>5s',3],
					'RP1':[None,'>10.3E',3],
					'RP2':[None,'>10.3E',3],
					'RP3':[None,'>10.3E',3],
					'RP4':[None,'>10.3E',3],
					'RP5':[None,'>10.3E',3],
					'RP6':[None,'>10.3E',3],
					'RP7':[None,'>10.3E',3],
					'ICP':[None,'>5s',4],
					'SPACE2':[None,'>5s',4],
					'ICP1':[None,'>10.3E',4],
					'ICP2':[None,'>10.3E',4],
					'ICP3':[None,'>10.3E',4],
					'ICP4':[None,'>10.3E',4],
					'ICP5':[None,'>10.3E',4],
					'ICP6':[None,'>10.3E',4],
					'ICP7':[None,'>10.3E',4],	
					 },
			'PARAMETERS':
					  {'NOITE':[None,'>2s',1],
					  	'KDATA':[1,'>2s',1],
					  	'MCYC':[9999,'>4s',1],
					  	'MSEC':[None,'>4s',1],
					  	'MCYPR':[30,'>4s',1],
						'MOP1':[1,'>1s',1],
						'MOP2':[0,'>1s',1],
						'MOP3':[0,'>1s',1],
						'MOP4':[0,'>1s',1],
						'MOP5':[1,'>1s',1],
						'MOP6':[0,'>1s',1],
						'MOP7':[2,'>1s',1],
						'MOP8':[0,'>1s',1],
						'MOP9':[0,'>1s',1],
						'MOP10':[0,'>1s',1],
						'MOP11':[0,'>1s',1],
						'MOP12':[2,'>1s',1],
						'MOP13':[0,'>1s',1],
						'MOP14':[0,'>1s',1],
						'MOP15':[0,'>1s',1],
						'MOP16':[4,'>1s',1],
						'MOP17':[None,'>1s',1],
						'MOP18':[None,'>1s',1],
						'MOP19':[None,'>1s',1],
						'MOP20':[None,'>1s',1],
						'MOP21':[2,'>1s',1],
						'MOP22':[None,'>1s',1],
						'MOP23':[None,'>1s',1],			
						'MOP24':[None,'>1s',1],
						'SPACE':[None,'>10s',1],
						'TEXTP':[None,'>10.3E',1],
						'BE':[None,'>10.3E',1],
						'TSTART':[-3.14E14,'>10.3E',2],
						'TIMAX':[300,'>10.3E',2],
						'DELTEN':[3.14E7,'>10.3E',2],
						'DELTMX':[None,'>10.3E',2],
						'ELST':['AA110','>5s',2],
						'SPACE2':[None,'>5s',2],
						'GF':[9.81,'>10.3E',2],
						'REDLT':[3.5,'>10.3E',2],
						'SCALE':[None,'>10.3E',2],
						'RE1':[1e-3,'>10.3E',3],
						'RE2':[None,'>10.3E',3],
						'U':[None,'>10.3E',3],
						'WUP':[None,'>10.3E',3],
						'WNR':[None,'>10.3E',3],
						'DFAC':[None,'>10.3E',3],
						'P':[100E5,'>20.13E',4,'EOS1'],
						'T':[250,'>20.13E',4,'EOS1'],
						'X':[1e5,'>20.13E',4,'EOS1']
					  },
			'DELTEN_LIST_FORMAT':[None,'>10.3E',2.1],
			'TIMES':{
				'ITI':[None,'>5s',1],
				'ITE':[None,'>5s',1],
				'DELAF':[None,'>10.3E',1],
				'TINTER':[None,'>10.3E',1],
				'TIMES_N':[None,'>10.3E',2]
				},
			'SOLVR':{
					'MATSLV':[None,'>1d',1],
					'SPACE':[None,'>2s',1],
					'ZPROCS':[None,'>2s',1],
					'SPACE2':[None,'>3s',1],
					'OPROCS':[None,'>2s',1],
					'RITMAX':[None,'>10.3E',1],
					'CLOSUR':[None,'>10.3E',1]
					},
			'RPCAP':{
					'IRP':[None,'>5s',1],
					'SPACE':[None,'>5s',1],
					'RP1':[None,'>10.3E',1],
					'RP2':[None,'>10.3E',1],
					'RP3':[None,'>10.3E',1],
					'RP4':[None,'>10.3E',1],
					'RP5':[None,'>10.3E',1],
					'RP6':[None,'>10.3E',1],
					'RP7':[None,'>10.3E',1],
					'ICP':[None,'>5s',2],
					'SPACE2':[None,'>5s',2],
					'ICP1':[None,'>10.3E',2],
					'ICP2':[None,'>10.3E',2],
					'ICP3':[None,'>10.3E',2],
					'ICP4':[None,'>10.3E',2],
					'ICP5':[None,'>10.3E',2],
					'ICP6':[None,'>10.3E',2],
					'ICP7':[None,'>10.3E',2],					
			},
			'MULTI':{
					 'NK':[None,'>5s',1],
					 'NEQ':[None,'>5s',1],
					 'NPH':[None,'>5s',1],
					 'NB':[None,'>5s',1],
					 'NKIN':[None,'>5s',1]
					},
			'GENER':{
					 'BLOCK':[None,'>5s',1],
					 'SL':[None,'>3s',1],
					 'NS':[None,'>2s',1],
					 'NSEQ':[None,'>5s',1],
					 'NADD':[None,'>5s',1],
					 'NADS':[None,'>5s',1],
					 'LTAB':[None,'>5s',1],
					 'SPACE':[None,'>5s',1],
					 'TYPE':[None,'>4s',1],
					 'ITAB':[None,'>1s',1],
					 'GX':[None,'>10.3E',1],
					 'EX':[None,'>10.3E',1],
					 'HG':[None,'>10.3E',1]
					 },
			'MOMOP':{
					'MOP2_1':[None,'>1s',1],
					'MOP2_2':[None,'>1s',1],
					'MOP2_3':[None,'>1s',1],
					'MOP2_4':[None,'>1s',1],
					'MOP2_5':[None,'>1s',1],
					'MOP2_6':[None,'>1s',1],
					'MOP2_7':[None,'>1s',1],
					'MOP2_8':[None,'>1s',1],
					'MOP2_9':[None,'>1s',1],
					'MOP2_10':[None,'>1s',1],
					'MOP2_11':[None,'>1s',1],
					'MOP2_12':[None,'>1s',1],
					'MOP2_13':[None,'>1s',1],
					'MOP2_14':[None,'>1s',1],
					'MOP2_15':[None,'>1s',1],
					'MOP2_16':[None,'>1s',1],
					'MOP2_17':[None,'>1s',1],
					'MOP2_18':[None,'>1s',1],
					'MOP2_19':[None,'>1s',1],
					'MOP2_20':[None,'>1s',1],
					'MOP2_21':[None,'>1s',1],
					'MOP2_22':[None,'>1s',1],
					'MOP2_23':[None,'>1s',1],
					'MOP2_25':[None,'>1s',1],
					'MOP2_26':[None,'>1s',1],
					'MOP2_27':[None,'>1s',1],
					'MOP2_28':[None,'>1s',1],
					'MOP2_29':[None,'>1s',1],
					'MOP2_30':[None,'>1s',1]
			         },
			'OUTPU':{
					 'FORMATS':['CSV','TECPLOT','PETRASIM','GNU'],
					 'FORMAT':['<20s','<10s'],
					 'ELEMENT_RELATED':{'MATERIAL':[type(None),type(None)],
					                    'ROCK TYPE':[type(None),type(None)],
					                    'MATERIAL NAME':[type(None),type(None)],
					                    'ROCK NAME':[type(None),type(None)],
					                    'ROCK TYPE NAME':[type(None),type(None)],
					                    'ABSOLUTE PERMEABILITY':[int,type(None)],
					                    'POROSITY':[type(None),type(None)],
					                    'TEMPERATURE':[type(None),type(None)],
					                    'PRESSURE':[int,type(None)],
					                    'SATURATION':[int,type(None)],
					                    'RELATIVE':[int,type(None)],
					                    'VISCOSITY':[int,type(None)],
					                    'DENSITY':[int,type(None)],
					                    'ENTHALPY':[int,type(None)],
					                    'MASS FRACTION':[int,type(None)],
					                    'DIFFUSION1':[int,type(None)],
					                    'DIFFUSION2':[int,type(None)],
					                    'PSAT':[type(None),type(None)],
					                    'PRIMARY':[int,type(None)],
					                    'SECONDARY':[int,int]
					                    },
					'CONNECTION_RELATED':{'TOTAL FLOW':[type(None),type(None)],
										  'TOTAL FLOW RATE':[type(None),type(None)],
										  'FLOW':[int,int],
										  'RATE':[int,int],
										  'FLOW RATE':[int,int],
										  'DIFFUSIVE FLOW':[int,int],
										  'HEAT FLOW':[int,int],
										  'VELOCITY':[int,type(None)],
										},
					'GENER_RELATED':{'GENERATION':[type(None),type(None)],
									 'GENERATION RATE':[type(None),type(None)],
									 'FLOWING ENTHALPY':[type(None),type(None)],
									 'FRACTIONAL FLOW':[int,type(None)],
									 'WELLBORE PRESSURE':[int,type(None)]}
					},
				'LAYERS':{'A':1,
						  'B':2,
						  'C':3,
						  'D':4,
						  'E':5,
						  'F':6,
						  'G':7,
						  'H':8,	
						  'I':9,
						  'J':11,
						  'K':12,
						  'L':13,
						  'M':14,
						  'N':15,
						  'O':16,
						  'P':17,
						  'Q':18,
						  'R':19,
						  'S':20,
						  'T':21,
						  'U':22,
						  'W':23,
						  'X':24,
						  'Y':25,
						  'Z':26,
						  '!':27,
						  '#':28,
						  '$':29,
						  '%':30,
						  '&':31,
						  '_':32,
						  '+':33,
						  '*':34,
						  '{':35,
						  '}':36,
						  '[':37,
						  ']':38,
						  '(':39,
						  ')':40,
						  ':':41}
		}


plot_conf_color={'T':['r','teal','crimson'],\
				 'P':['b','lightseagreen','teal'],\
				 'm':['g','goldenrod','royalblue'],
				 'ms':['indianred','darkcyan','slategrey'],
				 'ml':['navy','dodgerblue','peru'],
				 'h':['orangered','indigo','chocolate'],\
				 'SG':['m','gold','purple']}

plot_conf_marker={'real':['.',1],\
				  'current':["+",0.75],\
				  "previous":["^",0.75]}

structure={'calib':{'drawdown_cooling':{'images':None},
					'mh':{'images':None},
					'PT':{'images':{'layer_distribution':None}}
					},
			'input':{'cooling':None,
			         'drawdown':None,
			         'mh':None,
			         'PT':{'GIS':None,
			               'selection_PT':None,
			               'warm_up':None},
			         'survey':None,
			         'tubes':None},
			'mesh':{'from_amesh':None,
			        'from_leapfrog':None,
			        'GIS':None,
			        'images':None,
			        'to_steinar':None,
			        'vtu':None},
			'model':{'it2':None,
			          't2':{'prev':None,
			                'sources':None},
			        },
			'output':{
					  'mh':{'images':None,
					        'txt':{'prev':None}
					        },
					  'vtu':None,
					  'initial_conditions':None,
			          'PT':{'csv':{'prev':None},
			          		'evol':{'prev':None},
			          		'images':{'evol':None,
			          				  'layer':None,
			          				  'logging':None,
			          				  'real_layer':None},
			          		'json':{'prev':None,
			          				'evol':None},
			          		'txt':{'prev':None}
			          		}
			        },
			'scripts':None}

==> T2GEORES-0.1.95.tar.gz: T2GEORES-0.1.95/T2GEORES/formats.py <==
"""
The file contains several dictionaries which declare the format and default values from most of the parameters
for modeling.

formats_t2: represents the parameters from TOUGH2 base on sections. For instance, 'PARAMETERS' is a dictionary, every data
on it is formatted as following: 'PARAMETER1':[Default value,format,line section].

plot_conf_color: it gives three color for every main output parameter, the first is for real data, second for current output and final for 
previous run.

plot_conf_marker: gives the marker type and alpha value depending on the the of data in case same color is used when plotting.

structure: gives the fix structure of T2GEORES, necessary as workspace.

"""


initial_conditions={'EOS1':[
						    [100E5,'>20.13E',4,'P'],
						    [250,'>20.13E',4,'T'],
						    [1e5,'>20.13E',4,'X']]}

formats_t2={'TITLE':['TOUGH2 INPUT FILE','<80s',1],
			'ROCKS':{
					'MAT':[None,'>5s',1],
					'NAD':[None,'>5s',1],
					'DROK':[None,'>10.3E',1],
					'POR':[None,'>10.3E',1],
					'PER_X':[None,'>10.3E',1],
					'PER_Y':[None,'>10.3E',1],
					'PER_Z':[None,'>10.3E',1],
					'CWET':[None,'>10.3E',1],
					'SPHT':[None,'>10.3E',1],
					'COM':[None,'>10.3E',2],
					'EXPAN':[None,'>10.3E',2],
					'CDRY':[None,'>10.3E',2],
					'TORTX':[None,'>10.3E',2],
					'GK':[None,'>10.3E',2],
					'XKD3':[None,'>10.3E',2],
					'XKD4':[None,'>10.3E',2],
					'IRP':[None,'>5s',3],
					'SPACE':[None,'>5s',3],
					'RP1':[None,'>10.3E',3],
					'RP2':[None,'>10.3E',3],
					'RP3':[None,'>10.3E',3],
					'RP4':[None,'>10.3E',3],
					'RP5':[None,'>10.3E',3],
					'RP6':[None,'>10.3E',3],
					'RP7':[None,'>10.3E',3],
					'ICP':[None,'>5s',4],
					'SPACE2':[None,'>5s',4],
					'ICP1':[None,'>10.3E',4],
					'ICP2':[None,'>10.3E',4],
					'ICP3':[None,'>10.3E',4],
					'ICP4':[None,'>10.3E',4],
					'ICP5':[None,'>10.3E',4],
					'ICP6':[None,'>10.3E',4],
					'ICP7':[None,'>10.3E',4],	
					 },
			'PARAMETERS':
					  {'NOITE':[None,'>2s',1],
					  	'KDATA':[1,'>2s',1],
					  	'MCYC':[9999,'>4s',1],
					  	'MSEC':[None,'>4s',1],
					  	'MCYPR':[30,'>4s',1],
						'MOP1':[1,'>1s',1],
						'MOP2':[0,'>1s',1],
						'MOP3':[0,'>1s',1],
						'MOP4':[0,'>1s',1],
						'MOP5':[1,'>1s',1],
						'MOP6':[0,'>1s',1],
						'MOP7':[2,'>1s',1],
						'MOP8':[0,'>1s',1],
						'MOP9':[0,'>1s',1],
						'MOP10':[0,'>1s',1],
						'MOP11':[0,'>1s',1],
						'MOP12':[2,'>1s',1],
						'MOP13':[0,'>1s',1],
						'MOP14':[0,'>1s',1],
						'MOP15':[0,'>1s',1],
						'MOP16':[4,'>1s',1],
						'MOP17':[None,'>1s',1],
						'MOP18':[None,'>1s',1],
						'MOP19':[None,'>1s',1],
						'MOP20':[None,'>1s',1],
						'MOP21':[2,'>1s',1],
						'MOP22':[None,'>1s',1],
						'MOP23':[None,'>1s',1],			
						'MOP24':[None,'>1s',1],
						'SPACE':[None,'>10s',1],
						'TEXTP':[None,'>10.3E',1],
						'BE':[None,'>10.3E',1],
						'TSTART':[-3.14E14,'>10.3E',2],
						'TIMAX':[300,'>10.3E',2],
						'DELTEN':[3.14E7,'>10.3E',2],
						'DELTMX':[None,'>10.3E',2],
						'ELST':['AA110','>5s',2],
						'SPACE2':[None,'>5s',2],
						'GF':[9.81,'>10.3E',2],
						'REDLT':[3.5,'>10.3E',2],
						'SCALE':[None,'>10.3E',2],
						'RE1':[1e-3,'>10.3E',3],
						'RE2':[None,'>10.3E',3],
						'U':[None,'>10.3E',3],
						'WUP':[None,'>10.3E',3],
						'WNR':[None,'>10.3E',3],
						'DFAC':[None,'>10.3E',3],
						'P':[100E5,'>20.13E',4,'EOS1'],
						'T':[250,'>20.13E',4,'EOS1'],
						'X':[1e5,'>20.13E',4,'EOS1']
					  },
			'DELTEN_LIST_FORMAT':[None,'>10.3E',2.1],
			'TIMES':{
				'ITI':[None,'>5s',1],
				'ITE':[None,'>5s',1],
				'DELAF':[None,'>10.3E',1],
				'TINTER':[None,'>10.3E',1],
				'TIMES_N':[None,'>10.3E',2]
				},
			'SOLVR':{
					'MATSLV':[None,'>1d',1],
					'SPACE':[None,'>2s',1],
					'ZPROCS':[None,'>2s',1],
					'SPACE2':[None,'>3s',1],
					'OPROCS':[None,'>2s',1],
					'RITMAX':[None,'>10.3E',1],
					'CLOSUR':[None,'>10.3E',1]
					},
			'RPCAP':{
					'IRP':[None,'>5s',1],
					'SPACE':[None,'>5s',1],
					'RP1':[None,'>10.3E',1],
					'RP2':[None,'>10.3E',1],
					'RP3':[None,'>10.3E',1],
					'RP4':[None,'>10.3E',1],
					'RP5':[None,'>10.3E',1],
					'RP6':[None,'>10.3E',1],
					'RP7':[None,'>10.3E',1],
					'ICP':[None,'>5s',2],
					'SPACE2':[None,'>5s',2],
					'ICP1':[None,'>10.3E',2],
					'ICP2':[None,'>10.3E',2],
					'ICP3':[None,'>10.3E',2],
					'ICP4':[None,'>10.3E',2],
					'ICP5':[None,'>10.3E',2],
					'ICP6':[None,'>10.3E',2],
					'ICP7':[None,'>10.3E',2],					
			},
			'MULTI':{
					 'NK':[None,'>5s',1],
					 'NEQ':[None,'>5s',1],
					 'NPH':[None,'>5s',1],
					 'NB':[None,'>5s',1],
					 'NKIN':[None,'>5s',1]
					},
			'GENER':{
					 'BLOCK':[None,'>5s',1],
					 'SL':[None,'>3s',1],
					 'NS':[None,'>2s',1],
					 'NSEQ':[None,'>5s',1],
					 'NADD':[None,'>5s',1],
					 'NADS':[None,'>5s',1],
					 'LTAB':[None,'>5s',1],
					 'SPACE':[None,'>5s',1],
					 'TYPE':[None,'>4s',1],
					 'ITAB':[None,'>1s',1],
					 'GX':[None,'>10.3E',1],
					 'EX':[None,'>10.3E',1],
					 'HG':[None,'>10.3E',1]
					 },
			'MOMOP':{
					'MOP2_1':[None,'>1s',1],
					'MOP2_2':[None,'>1s',1],
					'MOP2_3':[None,'>1s',1],
					'MOP2_4':[None,'>1s',1],
					'MOP2_5':[None,'>1s',1],
					'MOP2_6':[None,'>1s',1],
					'MOP2_7':[None,'>1s',1],
					'MOP2_8':[None,'>1s',1],
					'MOP2_9':[None,'>1s',1],
					'MOP2_10':[None,'>1s',1],
					'MOP2_11':[None,'>1s',1],
					'MOP2_12':[None,'>1s',1],
					'MOP2_13':[None,'>1s',1],
					'MOP2_14':[None,'>1s',1],
					'MOP2_15':[None,'>1s',1],
					'MOP2_16':[None,'>1s',1],
					'MOP2_17':[None,'>1s',1],
					'MOP2_18':[None,'>1s',1],
					'MOP2_19':[None,'>1s',1],
					'MOP2_20':[None,'>1s',1],
					'MOP2_21':[None,'>1s',1],
					'MOP2_22':[None,'>1s',1],
					'MOP2_23':[None,'>1s',1],
					'MOP2_25':[None,'>1s',1],
					'MOP2_26':[None,'>1s',1],
					'MOP2_27':[None,'>1s',1],
					'MOP2_28':[None,'>1s',1],
					'MOP2_29':[None,'>1s',1],
					'MOP2_30':[None,'>1s',1],
					'MOP2_31':[None,'>1s',1],
					'MOP2_32':[None,'>1s',1]
			         },
			'OUTPU':{
					 'FORMATS':['CSV','TECPLOT','PETRASIM','GNU'],
					 'FORMAT':['<20s','<10s'],
					 'ELEMENT_RELATED':{'MATERIAL':[type(None),type(None)],
					                    'ROCK TYPE':[type(None),type(None)],
					                    'MATERIAL NAME':[type(None),type(None)],
					                    'ROCK NAME':[type(None),type(None)],
					                    'ROCK TYPE NAME':[type(None),type(None)],
					                    'ABSOLUTE PERMEABILITY':[int,type(None)],
					                    'POROSITY':[type(None),type(None)],
					                    'TEMPERATURE':[type(None),type(None)],
					                    'PRESSURE':[int,type(None)],
					                    'SATURATION':[int,type(None)],
					                    'RELATIVE':[int,type(None)],
					                    'VISCOSITY':[int,type(None)],
					                    'DENSITY':[int,type(None)],
					                    'ENTHALPY':[int,type(None)],
					                    'MASS FRACTION':[int,type(None)],
					                    'DIFFUSION1':[int,type(None)],
					                    'DIFFUSION2':[int,type(None)],
					                    'PSAT':[type(None),type(None)],
					                    'PRIMARY':[int,type(None)],
					                    'SECONDARY':[int,int]
					                    },
					'CONNECTION_RELATED':{'TOTAL FLOW':[type(None),type(None)],
										  'TOTAL FLOW RATE':[type(None),type(None)],
										  'FLOW':[int,int],
										  'RATE':[int,int],
										  'FLOW RATE':[int,int],
										  'DIFFUSIVE FLOW':[int,int],
										  'HEAT FLOW':[int,int],
										  'VELOCITY':[int,type(None)],
										},
					'GENER_RELATED':{'GENERATION':[type(None),type(None)],
									 'GENERATION RATE':[type(None),type(None)],
									 'FLOWING ENTHALPY':[type(None),type(None)],
									 'FRACTIONAL FLOW':[int,type(None)],
									 'WELLBORE PRESSURE':[int,type(None)]}
					},
				'LAYERS':{'A':1,
						  'B':2,
						  'C':3,
						  'D':4,
						  'E':5,
						  'F':6,
						  'G':7,
						  'H':8,	
						  'I':9,
						  'J':11,
						  'K':12,
						  'L':13,
						  'M':14,
						  'N':15,
						  'O':16,
						  'P':17,
						  'Q':18,
						  'R':19,
						  'S':20,
						  'T':21,
						  'U':22,
						  'W':23,
						  'X':24,
						  'Y':25,
						  'Z':26,
						  '!':27,
						  '#':28,
						  '$':29,
						  '%':30,
						  '&':31,
						  '_':32,
						  '+':33,
						  '*':34,
						  '{':35,
						  '}':36,
						  '[':37,
						  ']':38,
						  '(':39,
						  ')':40,
						  ':':41}
		}


plot_conf_color={'T':['r','teal','crimson'],\
				 'P':['b','lightseagreen','teal'],\
				 'm':['g','goldenrod','royalblue'],
				 'ms':['indianred','darkcyan','slategrey'],
				 'ml':['navy','dodgerblue','peru'],
				 'h':['orangered','indigo','chocolate'],\
				 'SG':['m','gold','purple']}

plot_conf_marker={'real':['.',1],\
				  'current':["+",0.75],\
				  "previous":["^",0.75]}

structure={'calib':{'drawdown_cooling':{'images':None},
					'mh':{'images':None},
					'PT':{'images':{'layer_distribution':None}}
					},
			'input':{'cooling':None,
			         'drawdown':{'images':None},
			         'mh':{'images':None,
			         		'filtered':{'images':None,
			         				 	'txt':None}
			         	   },
			         'PT':{'GIS':None,
			               'selection_PT':None,
			               'warm_up':None},
			         'survey':None,
			         'tubes':None},
			'mesh':{'from_amesh':None,
			        'from_leapfrog':None,
			        'GIS':None,
			        'images':None,
			        'to_steinar':None,
			        'vtu':None},
			'model':{'it2':None,
			          't2':{'prev':None,
			                'sources':None},
			        },
			'output':{
					  'mh':{'images':None,
					        'txt':{'prev':None}
					        },
					  'vtu':None,
					  'initial_conditions':None,
			          'PT':{'csv':{'prev':None},
			          		'evol':{'prev':None},
			          		'images':{'evol':None,
			          				  'layer':None,
			          				  'logging':None,
			          				  'real_layer':None},
			          		'json':{'prev':None,
			          				'evol':None},
			          		'txt':{'prev':None}
			          		}
			        },
			'scripts':None}
